package test.service;

import static org.junit.Assert.*;
import org.junit.Before;
import org.junit.After;
import org.junit.Test;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.SQLException;

import dao.StudentDAO;
import dao.impl.StudentDAOImpl;
import model.Student;
import service.StudentService;
import service.ServiceFactory;
import util.DatabaseUtil;

public class StudentServiceTest {
    
    private StudentService studentService;
    private StudentDAO studentDAO;
    private static final String TEST_STUDENT_ID = "S2024001";
    
    @Before
    public void setUp() throws SQLException {
        studentService = ServiceFactory.getStudentService();
        studentDAO = new StudentDAOImpl();
        // 清理测试数据
        cleanTestData();
        // 准备测试数据
        Student student = createTestStudent();
        studentDAO.insert(student);
    }
    
    @After
    public void tearDown() throws SQLException {
        cleanTestData();
    }
    
    private void cleanTestData() throws SQLException {
        try (Connection conn = DatabaseUtil.getConnection();
             PreparedStatement stmt = conn.prepareStatement("DELETE FROM students WHERE student_id = ?")) {
            stmt.setString(1, TEST_STUDENT_ID);
            stmt.executeUpdate();
        }
    }
    
    private Student createTestStudent() {
        Student student = new Student();
        student.setStudentId(TEST_STUDENT_ID);
        student.setName("测试学生");
        student.setClassName("2024级1班");
        student.setCollege("计算机学院");
        student.setMajor("软件工程");
        student.setContact("13900139000");
        student.setPassword("password123");
        return student;
    }
    
    @Test
    public void testLoginSuccess() {
        Student student = studentService.login(TEST_STUDENT_ID, "password123");
        assertNotNull("使用正确的学号和密码应该登录成功", student);
        assertEquals("登录后返回的学号应该匹配", TEST_STUDENT_ID, student.getStudentId());
        assertEquals("登录后返回的学生姓名应该匹配", "测试学生", student.getName());
    }
    
    @Test
    public void testLoginFailure() {
        Student student = studentService.login(TEST_STUDENT_ID, "wrongPassword");
        assertNull("使用错误的密码应该登录失败", student);
    }
    
    @Test
    public void testLoginWithNonexistentUser() {
        Student student = studentService.login("nonexistent", "password123");
        assertNull("使用不存在的学号应该登录失败", student);
    }
}
